Struct
WPEPlatformBufferFormatsBuilder
since: 2.0
Description [src]
struct WPEBufferFormatsBuilder {
/* No available fields */
}
Helper type to build a WPEBufferFormats.
Available since: 2.0
Instance methods
wpe_buffer_formats_builder_append_format
Append a new pair of format and modifier to the last group added to builder.
since: 2.0
wpe_buffer_formats_builder_append_group
Append a new group for device and usage to builder.
If device is NULL, the main device passed to wpe_buffer_formats_builder_new()
should be used.
since: 2.0
wpe_buffer_formats_builder_end
End the builder process and return the constructed WPEBufferFormats.
This function calls wpe_buffer_formats_builder_unref() on builder.
since: 2.0